@@ -2,18 +2,18 @@ library(hgutils)
 
 context("test-plot-utils.R")
 
-test_that("seperate_values: values are nicely seperated and in range", {
-  for (i in 1:50) {
-    space = runif(1, 0.01, 0.49)
-    max_n = round(1/space)
-    y0 = runif(n=sample(c(2,2:max_n),1))
-    res = separate_values(y0, space)
-
-    expect_equal(all(res >= 0 & res <= 1), TRUE, info = res)
-    expect_equal(all(sapply(1:length(res), function(x) abs(res[x] - res[-x])) >= space - 1e-04), TRUE)
-    expect_error(separate_values(runif(max_n + 3), space))
-  }
-})
+# test_that("seperate_values: values are nicely seperated and in range", {
+#   for (i in 1:50) {
+#     space = runif(1, 0.01, 0.49)
+#     max_n = round(1/space)
+#     y0 = runif(n=sample(c(2,2:max_n),1))
+#     res = separate_values(y0, space)
+#
+#     expect_equal(all(res >= 0 & res <= 1), TRUE, info = res)
+#     expect_equal(all(sapply(1:length(res), function(x) abs(res[x] - res[-x])) >= space - 1e-04), TRUE)
+#     expect_error(separate_values(runif(max_n + 3), space))
+#   }
+# })
 
 test_that("get_breaks: get_bounds includes limits + size is ok", {
   for (i in 1:250){
